@@ -25,7 +25,10 @@ os.environ["CUDA_DEVICE_ORDER"]="PCI_BUS_ID"
 os.environ["CUBLAS_WORKSPACE_CONFIG"] = ":4096:2" # This is crucial for reproducibility
 
 
-SUPPORTED_MODELS = ['lf_dnn', 'ef_lstm', 'tfn', 'lmf', 'mfn', 'graph_mfn', 'mult', 'misa', 'mlf_dnn', 'mtfn', 'mlmf', 'self_mm']
+SUPPORTED_MODELS = [
+    'lf_dnn', 'ef_lstm', 'tfn', 'lmf', 'mfn', 'graph_mfn', 
+    'mult', 'misa', 'mlf_dnn', 'mtfn', 'mlmf', 'self_mm', 'mmim'
+]
 SUPPORTED_DATASETS = ['mosi', 'mosei', 'sims']
 
 logger = logging.getLogger('MMSA')
@@ -261,16 +264,17 @@ try:
     from datetime import datetime
     from multiprocessing import Queue
     from sklearn.decomposition import PCA
-    from flask_sqlalchemy import SQLAlchemy
+    import mysql.connector
 except ImportError:
     logger.warning("SENA_run is not loaded due to missing dependencies. This is ok if you are not using M-SENA.")
     SENA_ENABLED = False
 
 if SENA_ENABLED:
     def SENA_run(
-        db: SQLAlchemy, table: dict, task_id: int, progress_q: Queue,
-        parameters: str, model_name: str, dataset_name: str, is_tune: bool,
-        tune_times: int, feature_T: str, feature_A: str, feature_V: str,
+        task_id: int, progress_q: Queue, db_url: str,
+        parameters: str, model_name: str, dataset_name: str,
+        is_tune: bool, tune_times: int,
+        feature_T: str, feature_A: str, feature_V: str,
         model_save_dir: str, res_save_dir: str, log_dir: str,
         gpu_ids: list, num_workers: int, seed: int, desc: str
     ) -> None:
@@ -279,10 +283,9 @@ if SENA_ENABLED:
         Run only one seed at a time.
 
         Parameters:
-            db (SQLAlchemy object): Used to store training results and task status.
-            table (dict): Name and definitions of database tables.
             task_id (int): Task id.
             progress_q (multiprocessing.Queue): Used to communicate with M-SENA Platform.
+            db_url (str): Database url.
             parameters (str): Training parameters in JSON.
             model_name (str): Model name.
             dataset_name (str): Dataset name.
@@ -300,12 +303,23 @@ if SENA_ENABLED:
             desc (str): Description.
         """
 
-        cur_task = None
+        cursor = None
         try:
             logger = logging.getLogger('app')
             logger.info(f"M-SENA Task {task_id} started.")
             time.sleep(1) # make sure task status is committed by the parent process
-            cur_task = db.session.query(table['Task']).filter(table['Task'].task_id == task_id).first()
+            # get db parameters
+            db_params = db_url.split('//')[1].split('@')[0].split(':')
+            db_user = db_params[0]
+            db_pass = db_params[1]
+            db_params = db_url.split('//')[1].split('@')[1].split('/')
+            db_host = db_params[0]
+            db_name = db_params[1]
+            # connect to db
+            db = mysql.connector.connect(
+                user=db_user, password=db_pass, host=db_host, database=db_name
+            )
+            cursor = db.cursor()
             # load training parameters
             if parameters == "": # use default config file
                 if is_tune: # TODO
@@ -333,17 +347,20 @@ if SENA_ENABLED:
             args_dump = args.copy()
             args_dump['device'] = str(args_dump['device'])
             custom_feature = False if (feature_A == "" and feature_V == "" and feature_T == "") else True
-            db_result = table['Result'](
-                dataset_name=dataset_name, model_name=model_name,
-                is_tune=is_tune, args=json.dumps(args_dump), save_model_path='',
-                loss_value=0.0, accuracy=0.0, f1=0.0, mae=0.0, corr=0.0,
-                description=desc, custom_feature=custom_feature
+            cursor.execute(
+                """
+                    INSERT INTO Result (dataset_name, model_name, is_tune, custom_feature, created_at,
+                     args, save_model_path, loss_value, accuracy, f1, mae, corr, description)
+                    VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
+                """,
+                (dataset_name, model_name, is_tune, custom_feature, datetime.now(), json.dumps(args_dump), '', 0, 0, 0, 0, 0, desc)
             )
-            db.session.add(db_result)
-            db.session.flush()
+            result_id = cursor.lastrowid
             # result_id is allocated now, so model_save_path can be determined
-            args['model_save_path'] = Path(model_save_dir) / f"{args['model_name']}-{args['dataset_name']}-{db_result.result_id}.pth"
-            db_result.save_model_path = args['model_save_path']
+            args['model_save_path'] = Path(model_save_dir) / f"{args['model_name']}-{args['dataset_name']}-{result_id}.pth"
+            cursor.execute(
+                "UPDATE Result SET save_model_path = %s WHERE result_id = %s", (str(args['model_save_path']), result_id)
+            )
             # start training
             try:
                 torch.cuda.set_device(args['device'])
@@ -354,16 +371,25 @@ if SENA_ENABLED:
                 results_dict = _run(args, num_workers, is_tune, from_sena=True)
                 # db operations
                 sample_dict = {}
-                samples = db.session.query(table['Dsample']).filter_by(dataset_name=dataset_name).all()
+                cursor2 = db.cursor(named_tuple=True)
+                cursor2.execute("SELECT * FROM Dsample WHERE dataset_name=%s", (dataset_name,))
+                samples = cursor2.fetchall()
                 for sample in samples:
                     key = sample.video_id + '$_$' + sample.clip_id
-                    sample_dict[key] = [sample.sample_id, sample.annotation]
+                    sample_dict[key] = (sample.sample_id, sample.annotation)
                 # update final results of test set
-                db_result.loss_value = results_dict['final_results']['test']['Loss']
-                db_result.accuracy = results_dict['final_results']['test']['Non0_acc_2']
-                db_result.f1 = results_dict['final_results']['test']['Non0_F1_score']
-                db_result.mae = results_dict['final_results']['test']['MAE']
-                db_result.corr = results_dict['final_results']['test']['Corr']
+                cursor.execute(
+                    """UPDATE Result SET loss_value = %s, accuracy = %s, f1 = %s,
+                    mae = %s, corr = %s WHERE result_id = %s""",
+                    (
+                        results_dict['final_results']['test']['Loss'],
+                        results_dict['final_results']['test']['Non0_acc_2'],
+                        results_dict['final_results']['test']['Non0_F1_score'],
+                        results_dict['final_results']['test']['MAE'],
+                        results_dict['final_results']['test']['Corr'],
+                        result_id
+                    )
+                )
                 # save features
                 if not is_tune:
                     logger.info("Running feature PCA ...")
@@ -381,8 +407,9 @@ if SENA_ENABLED:
                             cur_labels.extend(results_dict['final_results'][mode]['Labels'])
                         cur_labels = np.array(cur_labels)
                         label_index_dict = {}
-                        for k, v in args['annotations'].items():
-                            label_index_dict[k] = np.where(cur_labels == v)[0].tolist()
+                        label_index_dict['Negative'] = np.where(cur_labels < 0)[0].tolist()
+                        label_index_dict['Neutral'] = np.where(cur_labels == 0)[0].tolist()
+                        label_index_dict['Positive'] = np.where(cur_labels > 0)[0].tolist()
                         # handle features
                         cur_mode_features_2d = {}
                         cur_mode_features_3d = {}
@@ -415,14 +442,13 @@ if SENA_ENABLED:
                 for mode in ['train', 'valid', 'test']:
                     final_results = results_dict['final_results'][mode]
                     for i, cur_id in enumerate(final_results["Ids"]):
-                        payload = table['SResults'](
-                            result_id=db_result.result_id,
-                            sample_id=sample_dict[cur_id][0],
-                            label_value=sample_dict[cur_id][1],
-                            predict_value= 'Negative' if final_results["SResults"][i] < 0 else 'Positive',
-                            predict_value_r = final_results["SResults"][i]
+                        cursor.execute(
+                            """ INSERT INTO SResults (result_id, sample_id, label_value, predict_value, predict_value_r)
+                            VALUES (%s, %s, %s, %s, %s)""",
+                            (result_id, sample_dict[cur_id][0], sample_dict[cur_id][1],
+                            'Negative' if final_results["SResults"][i] < 0 else 'Positive',
+                            float(final_results["SResults"][i]))
                         )
-                        db.session.add(payload)
                 # update epoch results
                 cur_results = {}
                 for mode in ['train', 'valid', 'test']:
@@ -434,12 +460,10 @@ if SENA_ENABLED:
                         "mae":cur_epoch_results["MAE"],
                         "corr":cur_epoch_results["Corr"]
                     }
-                payload = table['EResult'](
-                    result_id=db_result.result_id,
-                    epoch_num=-1,
-                    results=json.dumps(cur_results)
+                cursor.execute(
+                    "INSERT INTO EResult (result_id, epoch_num, results) VALUES (%s, %s, %s)",
+                    (result_id, -1, json.dumps(cur_results))
                 )
-                db.session.add(payload)
 
                 epoch_num = len(results_dict['epoch_results']['train'])
                 for i in range(0, epoch_num):
@@ -453,27 +477,25 @@ if SENA_ENABLED:
                             "mae":cur_epoch_results["MAE"],
                             "corr":cur_epoch_results["Corr"]
                         }
-                    payload = table['EResult'](
-                        result_id=db_result.result_id,
-                        epoch_num=i + 1,
-                        results=json.dumps(cur_results)
+                    cursor.execute(
+                        "INSERT INTO EResult (result_id, epoch_num, results) VALUES (%s, %s, %s)",
+                        (result_id, i+1, json.dumps(cur_results))
                     )
-                    db.session.add(payload)
-                db.session.commit()
+                db.commit()
                 logger.info(f"Task {task_id} Finished.")
             except Exception as e:
                 logger.exception(e)
-                db.session.rollback()
+                db.rollback()
                 # TODO: remove saved features
                 raise e
-            cur_task.state = 1
+            cursor.execute("UPDATE Task SET state = %s WHERE task_id = %s", (1, task_id))
         except Exception as e:
             logger.exception(e)
             logger.error(f"Task {task_id} Error.")
-            if cur_task:
-                cur_task.state = 2
+            if cursor:
+                cursor.execute("UPDATE Task SET state = %s WHERE task_id = %s", (2, task_id))
         finally:
-            if cur_task:
-                cur_task.end_time = datetime.now()
-                db.session.commit()
+            if cursor:
+                cursor.execute("UPDATE Task SET end_time = %s WHERE task_id = %s", (datetime.now(), task_id))
+                db.commit()
             
\ No newline at end of file
